
=========
ctcsound7
=========

Python bindings for Csound using ctypes. Can be used from python >= 3.8

This bindings can be used with any version of csound >= 6.18. It is a drop-in replacement
of ctcsound


Installation  
------------

Csound needs to be installed in the system.


.. code::

	pip install ctcsound7

